@@ -1,11 +1,13 @@
 from __future__ import unicode_literals
 
 import logging
-import sys
 
 from pre_commit import color
+from pre_commit import output
 
 
+logger = logging.getLogger('pre_commit')
+
 LOG_LEVEL_COLORS = {
     'DEBUG': '',
     'INFO': '',
@@ -15,20 +17,23 @@ LOG_LEVEL_COLORS = {
 
 
 class LoggingHandler(logging.Handler):
-    def __init__(self, use_color, write=sys.stdout.write):
-        logging.Handler.__init__(self)
+    def __init__(self, use_color):
+        super(LoggingHandler, self).__init__()
         self.use_color = use_color
-        self.__write = write
 
     def emit(self, record):
-        self.__write(
-            u'{0}{1}\n'.format(
+        output.write_line(
+            '{} {}'.format(
                 color.format_color(
-                    '[{0}]'.format(record.levelname),
+                    '[{}]'.format(record.levelname),
                     LOG_LEVEL_COLORS[record.levelname],
                     self.use_color,
-                ) + ' ',
+                ),
                 record.getMessage(),
-            )
+            ),
         )
-        sys.stdout.flush()
+
+
+def add_logging_handler(*args, **kwargs):
+    logger.addHandler(LoggingHandler(*args, **kwargs))
+    logger.setLevel(logging.INFO)
