@@ -14,8 +14,10 @@ from pre_commit.commands.clean import clean
 from pre_commit.commands.install_uninstall import install
 from pre_commit.commands.install_uninstall import install_hooks
 from pre_commit.commands.install_uninstall import uninstall
+from pre_commit.commands.migrate_config import migrate_config
 from pre_commit.commands.run import run
 from pre_commit.commands.sample_config import sample_config
+from pre_commit.commands.try_repo import try_repo
 from pre_commit.error_handler import error_handler
 from pre_commit.logging_handler import add_logging_handler
 from pre_commit.runner import Runner
@@ -40,17 +42,58 @@ def _add_color_option(parser):
 
 def _add_config_option(parser):
     parser.add_argument(
-        '-c', '--config', default='.pre-commit-config.yaml',
+        '-c', '--config', default=C.CONFIG_FILE,
         help='Path to alternate config file',
     )
 
 
+def _add_hook_type_option(parser):
+    parser.add_argument(
+        '-t', '--hook-type', choices=('pre-commit', 'pre-push', 'commit-msg'),
+        default='pre-commit',
+    )
+
+
+def _add_run_options(parser):
+    parser.add_argument('hook', nargs='?', help='A single hook-id to run')
+    parser.add_argument('--verbose', '-v', action='store_true', default=False)
+    parser.add_argument(
+        '--origin', '-o',
+        help="The origin branch's commit_id when using `git push`.",
+    )
+    parser.add_argument(
+        '--source', '-s',
+        help="The remote branch's commit_id when using `git push`.",
+    )
+    parser.add_argument(
+        '--commit-msg-filename',
+        help='Filename to check when running during `commit-msg`',
+    )
+    parser.add_argument(
+        '--hook-stage', choices=C.STAGES, default='commit',
+        help='The stage during which the hook is fired.  One of %(choices)s',
+    )
+    parser.add_argument(
+        '--show-diff-on-failure', action='store_true',
+        help='When hooks fail, run `git diff` directly afterward.',
+    )
+    mutex_group = parser.add_mutually_exclusive_group(required=False)
+    mutex_group.add_argument(
+        '--all-files', '-a', action='store_true', default=False,
+        help='Run on all the files in the repo.',
+    )
+    mutex_group.add_argument(
+        '--files', nargs='*', default=[],
+        help='Specific filenames to run hooks on.',
+    )
+
+
 def main(argv=None):
     argv = argv if argv is not None else sys.argv[1:]
     argv = [five.to_text(arg) for arg in argv]
     parser = argparse.ArgumentParser()
 
-    # http://stackoverflow.com/a/8521644/812183
+    # https://stackoverflow.com/a/8521644/812183
     parser.add_argument(
         '-V', '--version',
         action='version',
@@ -75,14 +118,11 @@ def main(argv=None):
             'in the config file.'
         ),
     )
-    install_parser.add_argument(
-        '-t', '--hook-type', choices=('pre-commit', 'pre-push', 'commit-msg'),
-        default='pre-commit',
-    )
+    _add_hook_type_option(install_parser)
     install_parser.add_argument(
         '--allow-missing-config', action='store_true', default=False,
         help=(
-            'Whether to allow a missing `pre-config` configuration file '
+            'Whether to allow a missing `pre-commit` configuration file '
             'or exit with a failure code.'
         ),
     )
@@ -103,10 +143,7 @@ def main(argv=None):
     )
     _add_color_option(uninstall_parser)
     _add_config_option(uninstall_parser)
-    uninstall_parser.add_argument(
-        '-t', '--hook-type', choices=('pre-commit', 'pre-push'),
-        default='pre-commit',
-    )
+    _add_hook_type_option(uninstall_parser)
 
     clean_parser = subparsers.add_parser(
         'clean', help='Clean out pre-commit files.',
@@ -129,55 +166,22 @@ def main(argv=None):
             'tagged version (the default behavior).'
         ),
     )
+    autoupdate_parser.add_argument(
+        '--repo', dest='repos', action='append', metavar='REPO',
+        help='Only update this repository -- may be specified multiple times.',
+    )
+
+    migrate_config_parser = subparsers.add_parser(
+        'migrate-config',
+        help='Migrate list configuration to new map configuration.',
+    )
+    _add_color_option(migrate_config_parser)
+    _add_config_option(migrate_config_parser)
 
     run_parser = subparsers.add_parser('run', help='Run hooks.')
     _add_color_option(run_parser)
     _add_config_option(run_parser)
-    run_parser.add_argument('hook', nargs='?', help='A single hook-id to run')
-    run_parser.add_argument(
-        '--no-stash', default=False, action='store_true',
-        help='Use this option to prevent auto stashing of unstaged files.',
-    )
-    run_parser.add_argument(
-        '--verbose', '-v', action='store_true', default=False,
-    )
-    run_parser.add_argument(
-        '--origin', '-o',
-        help="The origin branch's commit_id when using `git push`.",
-    )
-    run_parser.add_argument(
-        '--source', '-s',
-        help="The remote branch's commit_id when using `git push`.",
-    )
-    run_parser.add_argument(
-        '--commit-msg-filename',
-        help='Filename to check when running during `commit-msg`',
-    )
-    run_parser.add_argument(
-        '--allow-unstaged-config', default=False, action='store_true',
-        help=(
-            'Allow an unstaged config to be present.  Note that this will '
-            'be stashed before parsing unless --no-stash is specified.'
-        ),
-    )
-    run_parser.add_argument(
-        '--hook-stage', choices=('commit', 'push', 'commit-msg'),
-        default='commit',
-        help='The stage during which the hook is fired e.g. commit or push.',
-    )
-    run_parser.add_argument(
-        '--show-diff-on-failure', action='store_true',
-        help='When hooks fail, run `git diff` directly afterward.',
-    )
-    run_mutex_group = run_parser.add_mutually_exclusive_group(required=False)
-    run_mutex_group.add_argument(
-        '--all-files', '-a', action='store_true', default=False,
-        help='Run on all the files in the repo.  Implies --no-stash.',
-    )
-    run_mutex_group.add_argument(
-        '--files', nargs='*', default=[],
-        help='Specific filenames to run hooks on.',
-    )
+    _add_run_options(run_parser)
 
     sample_config_parser = subparsers.add_parser(
         'sample-config', help='Produce a sample {} file'.format(C.CONFIG_FILE),
@@ -185,6 +189,24 @@ def main(argv=None):
     _add_color_option(sample_config_parser)
     _add_config_option(sample_config_parser)
 
+    try_repo_parser = subparsers.add_parser(
+        'try-repo',
+        help='Try the hooks in a repository, useful for developing new hooks.',
+    )
+    _add_color_option(try_repo_parser)
+    _add_config_option(try_repo_parser)
+    try_repo_parser.add_argument(
+        'repo', help='Repository to source hooks from.',
+    )
+    try_repo_parser.add_argument(
+        '--ref', '--rev',
+        help=(
+            'Manually select a rev to run against, otherwise the `HEAD` '
+            'revision will be used.'
+        ),
+    )
+    _add_run_options(try_repo_parser)
+
     help = subparsers.add_parser(
         'help', help='Show help for a specific command.',
     )
@@ -226,11 +248,19 @@ def main(argv=None):
         elif args.command == 'autoupdate':
             if args.tags_only:
                 logger.warning('--tags-only is the default')
-            return autoupdate(runner, tags_only=not args.bleeding_edge)
+            return autoupdate(
+                runner,
+                tags_only=not args.bleeding_edge,
+                repos=args.repos,
+            )
+        elif args.command == 'migrate-config':
+            return migrate_config(runner)
         elif args.command == 'run':
             return run(runner, args)
         elif args.command == 'sample-config':
             return sample_config()
+        elif args.command == 'try-repo':
+            return try_repo(args)
         else:
             raise NotImplementedError(
                 'Command {} not implemented.'.format(args.command),
